@@ -150,3 +150,15 @@ test_that("contained intervals are merged issue #176", {
   res <- bed_merge(x)
   expect_true(nrow(res) == 1)
 })
+
+test_that("is_merged identifies previously merged tbls", {
+  x <- tibble::tribble(
+    ~chrom, ~start, ~end,
+    'chr1',  1,     10,
+    'chr1',  2,     5,
+    'chr1',  7,     9
+  )
+  expect_false(is_merged(x))
+  res <- bed_merge(x)
+  expect_true(is_merged(res))
+})
