@@ -2,7 +2,7 @@ context("reading BED files")
 
 bed3_path <- system.file('extdata', '3fields.bed.gz', package = 'valr')
 bed6_path <- system.file('extdata', '6fields.bed.gz', package = 'valr')
-bed12_path <- system.file('extdata', 'mm9.bed12.gz', package = 'valr')
+bed12_path <- system.file('extdata', 'mm9.refGene.bed.gz', package = 'valr')
 bedgraph_path <- system.file('extdata', 'test.bg.gz', package = 'valr')
 narrowpeak_path <- system.file('extdata', 'sample.narrowPeak.gz', package = 'valr')
 broadpeak_path <- system.file('extdata', 'sample.broadPeak.gz', package = 'valr')
