@@ -1,12 +1,11 @@
 context('utils')
 
-
-x <- tibble::tribble(
+x <- trbl_interval(
   ~chrom, ~start, ~end,
   "chr1", 1     , 100,
   "chr1", 200,    500
 )
-y <- tibble::tribble(
+y <- trbl_interval(
   ~chrom, ~start, ~end,
   "chr1", 1     , 100,
   "chr1", 200,    500
@@ -14,35 +13,35 @@ y <- tibble::tribble(
 
 test_that("NULL is return when there are no shared groups, shared_groups()", {
   res <- shared_groups(x, y)
-  expect_null(res) 
+  expect_null(res)
 })
 
 test_that("only shared groups are return, shared_groups()", {
-  x <- tibble::tribble(
+  x <- trbl_interval(
     ~chrom, ~start, ~end,
     "chr1", 1     , 100,
     "chr1", 200,    500
   ) %>% group_by(chrom, start, end)
-  
+
   res <- shared_groups(x, y)
-  expect_true(length(res) == 1 && res == "chrom") 
+  expect_true(length(res) == 1 && res == "chrom")
 })
 
 
-x <- tibble::frame_data(
+x <- trbl_interval(
   ~end,  ~chrom,   ~start, ~value,
   75,  "chr1",    125,    10
 )
 
-y <- tibble::frame_data(
+y <- trbl_interval(
   ~chrom,   ~start,    ~end,  ~scores,
   "chr1",    50,       100,  1.2,
   "chr1",    100,       150,  2.4
 )
 
-test_that("x columns are reordered based on y, format_bed()", {
-  res <- format_bed(x, y)
-  
+test_that("x columns are reordered based on y, reorder_names()", {
+  res <- reorder_names(x, y)
+
   pred <- intersect(colnames(y), colnames(res))
   n <- length(pred)
 
